Mp4RangeResponse class

Constructors

Mp4RangeResponse({required int start, required int end, required int totalLength, required bool partial})
const
Mp4RangeResponse.fromRequest({required int start, required int end, required int totalLength, required bool partial})
factory

Properties

contentLength int
no setter
contentRangeHeader String?
no setter
end int
final
hashCode int
The hash code for this object.
no setterinherited
partial bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final
totalLength int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited