close method
Shuts down the proxy server and cancels the health check timer.
Implementation
Future<void> close() async {
_healthCheckTimer?.cancel();
_healthCheckTimer = null;
await server?.close();
server = null;
}
Shuts down the proxy server and cancels the health check timer.
Future<void> close() async {
_healthCheckTimer?.cancel();
_healthCheckTimer = null;
await server?.close();
server = null;
}